Class: MusicubeApiClientRuby::FileSmallDTO

Inherits:
Object
  • Object
show all
Defined in:
lib/musicube_api_client_ruby/models/file_small_dto.rb

Overview

Reduced details on a file that has been uploaded for auto-tagging or audio-recognition purposes.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FileSmallDTO

Initializes the object



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 129

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `MusicubeApiClientRuby::FileSmallDTO` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `MusicubeApiClientRuby::FileSmallDTO`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'extension')
    self.extension = attributes[:'extension']
  end

  if attributes.key?(:'error_message')
    self.error_message = attributes[:'error_message']
  end

  if attributes.key?(:'object_key')
    self.object_key = attributes[:'object_key']
  end

  if attributes.key?(:'upload_start_time')
    self.upload_start_time = attributes[:'upload_start_time']
  end

  if attributes.key?(:'upload_end_time')
    self.upload_end_time = attributes[:'upload_end_time']
  end

  if attributes.key?(:'fingerprint_status')
    self.fingerprint_status = attributes[:'fingerprint_status']
  end

  if attributes.key?(:'fingerprint_start_time')
    self.fingerprint_start_time = attributes[:'fingerprint_start_time']
  end

  if attributes.key?(:'fingerprint_end_time')
    self.fingerprint_end_time = attributes[:'fingerprint_end_time']
  end

  if attributes.key?(:'inference_status')
    self.inference_status = attributes[:'inference_status']
  end

  if attributes.key?(:'inference_start_time')
    self.inference_start_time = attributes[:'inference_start_time']
  end

  if attributes.key?(:'inference_end_time')
    self.inference_end_time = attributes[:'inference_end_time']
  end

  if attributes.key?(:'error_time')
    self.error_time = attributes[:'error_time']
  end

  if attributes.key?(:'folder')
    self.folder = attributes[:'folder']
  end
end

Instance Attribute Details

#error_messageObject

Returns the value of attribute error_message.



26
27
28
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 26

def error_message
  @error_message
end

#error_timeObject

Returns the value of attribute error_time.



48
49
50
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 48

def error_time
  @error_time
end

#extensionObject

extension of the file



24
25
26
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 24

def extension
  @extension
end

#fingerprint_end_timeObject

Returns the value of attribute fingerprint_end_time.



39
40
41
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 39

def fingerprint_end_time
  @fingerprint_end_time
end

#fingerprint_start_timeObject

Returns the value of attribute fingerprint_start_time.



37
38
39
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 37

def fingerprint_start_time
  @fingerprint_start_time
end

#fingerprint_statusObject

status of the audio recognition



35
36
37
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 35

def fingerprint_status
  @fingerprint_status
end

#folderObject

Returns the value of attribute folder.



50
51
52
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 50

def folder
  @folder
end

#idObject

Returns the value of attribute id.



21
22
23
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 21

def id
  @id
end

#inference_end_timeObject

Returns the value of attribute inference_end_time.



46
47
48
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 46

def inference_end_time
  @inference_end_time
end

#inference_start_timeObject

Returns the value of attribute inference_start_time.



44
45
46
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 44

def inference_start_time
  @inference_start_time
end

#inference_statusObject

status of the auto-tagging



42
43
44
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 42

def inference_status
  @inference_status
end

#nameObject

Returns the value of attribute name.



19
20
21
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 19

def name
  @name
end

#object_keyObject

Returns the value of attribute object_key.



28
29
30
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 28

def object_key
  @object_key
end

#upload_end_timeObject

Returns the value of attribute upload_end_time.



32
33
34
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 32

def upload_end_time
  @upload_end_time
end

#upload_start_timeObject

Returns the value of attribute upload_start_time.



30
31
32
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 30

def upload_start_time
  @upload_start_time
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



96
97
98
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 96

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 75

def self.attribute_map
  {
    :'name' => :'name',
    :'id' => :'id',
    :'extension' => :'extension',
    :'error_message' => :'error_message',
    :'object_key' => :'objectKey',
    :'upload_start_time' => :'uploadStartTime',
    :'upload_end_time' => :'uploadEndTime',
    :'fingerprint_status' => :'fingerprintStatus',
    :'fingerprint_start_time' => :'fingerprintStartTime',
    :'fingerprint_end_time' => :'fingerprintEndTime',
    :'inference_status' => :'inferenceStatus',
    :'inference_start_time' => :'inferenceStartTime',
    :'inference_end_time' => :'inferenceEndTime',
    :'error_time' => :'error_time',
    :'folder' => :'folder'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



314
315
316
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 314

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



122
123
124
125
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 122

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 101

def self.openapi_types
  {
    :'name' => :'String',
    :'id' => :'Integer',
    :'extension' => :'String',
    :'error_message' => :'String',
    :'object_key' => :'String',
    :'upload_start_time' => :'Time',
    :'upload_end_time' => :'Time',
    :'fingerprint_status' => :'String',
    :'fingerprint_start_time' => :'Time',
    :'fingerprint_end_time' => :'Time',
    :'inference_status' => :'String',
    :'inference_start_time' => :'Time',
    :'inference_end_time' => :'Time',
    :'error_time' => :'Time',
    :'folder' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 279

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      id == o.id &&
      extension == o.extension &&
      error_message == o.error_message &&
      object_key == o.object_key &&
      upload_start_time == o.upload_start_time &&
      upload_end_time == o.upload_end_time &&
      fingerprint_status == o.fingerprint_status &&
      fingerprint_start_time == o.fingerprint_start_time &&
      fingerprint_end_time == o.fingerprint_end_time &&
      inference_status == o.inference_status &&
      inference_start_time == o.inference_start_time &&
      inference_end_time == o.inference_end_time &&
      error_time == o.error_time &&
      folder == o.folder
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 345

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = MusicubeApiClientRuby.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 416

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 321

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


301
302
303
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 301

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



307
308
309
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 307

def hash
  [name, id, extension, error_message, object_key, upload_start_time, upload_end_time, fingerprint_status, fingerprint_start_time, fingerprint_end_time, inference_status, inference_start_time, inference_end_time, error_time, folder].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 205

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @extension.nil?
    invalid_properties.push('invalid value for "extension", extension cannot be nil.')
  end

  if @object_key.nil?
    invalid_properties.push('invalid value for "object_key", object_key cannot be nil.')
  end

  if @folder.nil?
    invalid_properties.push('invalid value for "folder", folder cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



392
393
394
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 392

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 398

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



386
387
388
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 386

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/musicube_api_client_ruby/models/file_small_dto.rb', line 232

def valid?
  return false if @name.nil?
  return false if @id.nil?
  return false if @extension.nil?
  extension_validator = EnumAttributeValidator.new('String', ["mp3", "wav", "flac"])
  return false unless extension_validator.valid?(@extension)
  return false if @object_key.nil?
  fingerprint_status_validator = EnumAttributeValidator.new('String', ["processing", "error", "found", "not_found", "not_started"])
  return false unless fingerprint_status_validator.valid?(@fingerprint_status)
  inference_status_validator = EnumAttributeValidator.new('String', ["processing", "error", "done", "not_started"])
  return false unless inference_status_validator.valid?(@inference_status)
  return false if @folder.nil?
  true
end