Class: MusicubeApiClientRuby::PlaylistLargeDTO

Inherits:
Object
  • Object
show all
Defined in:
lib/musicube_api_client_ruby/models/playlist_large_dto.rb

Overview

Details on a playlist

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PlaylistLargeDTO

Initializes the object



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `MusicubeApiClientRuby::PlaylistLargeDTO` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `MusicubeApiClientRuby::PlaylistLargeDTO`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'usages')
    if (value = attributes[:'usages']).is_a?(Array)
      self.usages = value
    end
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.key?(:'asset_url')
    self.asset_url = attributes[:'asset_url']
  end

  if attributes.key?(:'pretzel_tier')
    self.pretzel_tier = attributes[:'pretzel_tier']
  end

  if attributes.key?(:'usage')
    self.usage = attributes[:'usage']
  end

  if attributes.key?(:'songtradr_playlist_guid')
    self.songtradr_playlist_guid = attributes[:'songtradr_playlist_guid']
  end

  if attributes.key?(:'tracks')
    if (value = attributes[:'tracks']).is_a?(Array)
      self.tracks = value
    end
  end
end

Instance Attribute Details

#asset_urlObject

Returns the value of attribute asset_url.



31
32
33
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 31

def asset_url
  @asset_url
end

#createdObject

Returns the value of attribute created.



27
28
29
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 27

def created
  @created
end

#descriptionObject

Returns the value of attribute description.



23
24
25
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 23

def description
  @description
end

#nameObject

Returns the value of attribute name.



19
20
21
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 19

def name
  @name
end

#pretzel_tierObject

Returns the value of attribute pretzel_tier.



33
34
35
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 33

def pretzel_tier
  @pretzel_tier
end

#songtradr_playlist_guidObject

Returns the value of attribute songtradr_playlist_guid.



37
38
39
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 37

def songtradr_playlist_guid
  @songtradr_playlist_guid
end

#stateObject

Returns the value of attribute state.



21
22
23
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 21

def state
  @state
end

#tracksObject

Returns the value of attribute tracks.



39
40
41
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 39

def tracks
  @tracks
end

#updatedObject

Returns the value of attribute updated.



29
30
31
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 29

def updated
  @updated
end

#usageObject

Returns the value of attribute usage.



35
36
37
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 35

def usage
  @usage
end

#usagesObject

Returns the value of attribute usages.



25
26
27
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 25

def usages
  @usages
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 81

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 64

def self.attribute_map
  {
    :'name' => :'name',
    :'state' => :'state',
    :'description' => :'description',
    :'usages' => :'usages',
    :'created' => :'created',
    :'updated' => :'updated',
    :'asset_url' => :'assetURL',
    :'pretzel_tier' => :'pretzelTier',
    :'usage' => :'usage',
    :'songtradr_playlist_guid' => :'songtradrPlaylistGuid',
    :'tracks' => :'tracks'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



235
236
237
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 235

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 86

def self.openapi_types
  {
    :'name' => :'String',
    :'state' => :'String',
    :'description' => :'String',
    :'usages' => :'Array<UsageDTO>',
    :'created' => :'Time',
    :'updated' => :'Time',
    :'asset_url' => :'String',
    :'pretzel_tier' => :'String',
    :'usage' => :'String',
    :'songtradr_playlist_guid' => :'String',
    :'tracks' => :'Array<RecordingPlaylistDTO>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 204

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      state == o.state &&
      description == o.description &&
      usages == o.usages &&
      created == o.created &&
      updated == o.updated &&
      asset_url == o.asset_url &&
      pretzel_tier == o.pretzel_tier &&
      usage == o.usage &&
      songtradr_playlist_guid == o.songtradr_playlist_guid &&
      tracks == o.tracks
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 266

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = MusicubeApiClientRuby.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 337

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 242

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


222
223
224
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 222

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



228
229
230
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 228

def hash
  [name, state, description, usages, created, updated, asset_url, pretzel_tier, usage, songtradr_playlist_guid, tracks].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



174
175
176
177
178
179
180
181
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 174

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



313
314
315
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 313

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 319

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



307
308
309
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 307

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



185
186
187
188
189
190
# File 'lib/musicube_api_client_ruby/models/playlist_large_dto.rb', line 185

def valid?
  return false if @name.nil?
  state_validator = EnumAttributeValidator.new('String', ["active", "draft"])
  return false unless state_validator.valid?(@state)
  true
end