Class: MusicubeApiClientRuby::UserDTO

Inherits:
Object
  • Object
show all
Defined in:
lib/musicube_api_client_ruby/models/user_dto.rb

Overview

All details on a user.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UserDTO

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `MusicubeApiClientRuby::UserDTO` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `MusicubeApiClientRuby::UserDTO`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'email_address')
    self.email_address = attributes[:'email_address']
  end

  if attributes.key?(:'company_name')
    self.company_name = attributes[:'company_name']
  end

  if attributes.key?(:'is_admin')
    self.is_admin = attributes[:'is_admin']
  end

  if attributes.key?(:'full_search_allowed')
    self.full_search_allowed = attributes[:'full_search_allowed']
  end

  if attributes.key?(:'voice_search_allowed')
    self.voice_search_allowed = attributes[:'voice_search_allowed']
  end

  if attributes.key?(:'recording_detail_allowed')
    self.recording_detail_allowed = attributes[:'recording_detail_allowed']
  end

  if attributes.key?(:'artist_detail_allowed')
    self.artist_detail_allowed = attributes[:'artist_detail_allowed']
  end

  if attributes.key?(:'playlist_prediction_allowed')
    self.playlist_prediction_allowed = attributes[:'playlist_prediction_allowed']
  end

  if attributes.key?(:'widgets_allowed')
    self.widgets_allowed = attributes[:'widgets_allowed']
  end

  if attributes.key?(:'signup_allowed')
    self. = attributes[:'signup_allowed']
  end

  if attributes.key?(:'upload_allowed')
    self.upload_allowed = attributes[:'upload_allowed']
  end

  if attributes.key?(:'fingerprint_allowed')
    self.fingerprint_allowed = attributes[:'fingerprint_allowed']
  end

  if attributes.key?(:'audiotagging_allowed')
    self.audiotagging_allowed = attributes[:'audiotagging_allowed']
  end

  if attributes.key?(:'b2b_allowed')
    self.b2b_allowed = attributes[:'b2b_allowed']
  end

  if attributes.key?(:'editor_allowed')
    self.editor_allowed = attributes[:'editor_allowed']
  end

  if attributes.key?(:'reduced_musical_features')
    self.reduced_musical_features = attributes[:'reduced_musical_features']
  end

  if attributes.key?(:'confirmed')
    self.confirmed = attributes[:'confirmed']
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  end

  if attributes.key?(:'admin')
    self.admin = attributes[:'admin']
  end
end

Instance Attribute Details

#adminObject

Returns the value of attribute admin.



57
58
59
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 57

def admin
  @admin
end

#artist_detail_allowedObject

Returns the value of attribute artist_detail_allowed.



33
34
35
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 33

def artist_detail_allowed
  @artist_detail_allowed
end

#audiotagging_allowedObject

Returns the value of attribute audiotagging_allowed.



45
46
47
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 45

def audiotagging_allowed
  @audiotagging_allowed
end

#b2b_allowedObject

Returns the value of attribute b2b_allowed.



47
48
49
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 47

def b2b_allowed
  @b2b_allowed
end

#company_nameObject

Returns the value of attribute company_name.



23
24
25
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 23

def company_name
  @company_name
end

#confirmedObject

Returns the value of attribute confirmed.



53
54
55
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 53

def confirmed
  @confirmed
end

#editor_allowedObject

Returns the value of attribute editor_allowed.



49
50
51
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 49

def editor_allowed
  @editor_allowed
end

#email_addressObject

Returns the value of attribute email_address.



21
22
23
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 21

def email_address
  @email_address
end

#fingerprint_allowedObject

Returns the value of attribute fingerprint_allowed.



43
44
45
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 43

def fingerprint_allowed
  @fingerprint_allowed
end

#full_search_allowedObject

Returns the value of attribute full_search_allowed.



27
28
29
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 27

def full_search_allowed
  @full_search_allowed
end

#is_adminObject

Returns the value of attribute is_admin.



25
26
27
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 25

def is_admin
  @is_admin
end

#languageObject

Returns the value of attribute language.



55
56
57
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 55

def language
  @language
end

#playlist_prediction_allowedObject

Returns the value of attribute playlist_prediction_allowed.



35
36
37
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 35

def playlist_prediction_allowed
  @playlist_prediction_allowed
end

#recording_detail_allowedObject

Returns the value of attribute recording_detail_allowed.



31
32
33
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 31

def recording_detail_allowed
  @recording_detail_allowed
end

#reduced_musical_featuresObject

Returns the value of attribute reduced_musical_features.



51
52
53
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 51

def reduced_musical_features
  @reduced_musical_features
end

#signup_allowedObject

Returns the value of attribute signup_allowed.



39
40
41
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 39

def 
  @signup_allowed
end

#upload_allowedObject

Returns the value of attribute upload_allowed.



41
42
43
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 41

def upload_allowed
  @upload_allowed
end

#usernameObject

Returns the value of attribute username.



19
20
21
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 19

def username
  @username
end

#voice_search_allowedObject

Returns the value of attribute voice_search_allowed.



29
30
31
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 29

def voice_search_allowed
  @voice_search_allowed
end

#widgets_allowedObject

Returns the value of attribute widgets_allowed.



37
38
39
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 37

def widgets_allowed
  @widgets_allowed
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 86

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 60

def self.attribute_map
  {
    :'username' => :'username',
    :'email_address' => :'emailAddress',
    :'company_name' => :'companyName',
    :'is_admin' => :'isAdmin',
    :'full_search_allowed' => :'fullSearchAllowed',
    :'voice_search_allowed' => :'voiceSearchAllowed',
    :'recording_detail_allowed' => :'recordingDetailAllowed',
    :'artist_detail_allowed' => :'artistDetailAllowed',
    :'playlist_prediction_allowed' => :'playlistPredictionAllowed',
    :'widgets_allowed' => :'widgetsAllowed',
    :'signup_allowed' => :'signupAllowed',
    :'upload_allowed' => :'uploadAllowed',
    :'fingerprint_allowed' => :'fingerprintAllowed',
    :'audiotagging_allowed' => :'audiotaggingAllowed',
    :'b2b_allowed' => :'b2bAllowed',
    :'editor_allowed' => :'editorAllowed',
    :'reduced_musical_features' => :'reducedMusicalFeatures',
    :'confirmed' => :'confirmed',
    :'language' => :'language',
    :'admin' => :'admin'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



363
364
365
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 363

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



117
118
119
120
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 117

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 91

def self.openapi_types
  {
    :'username' => :'String',
    :'email_address' => :'String',
    :'company_name' => :'String',
    :'is_admin' => :'Boolean',
    :'full_search_allowed' => :'Boolean',
    :'voice_search_allowed' => :'Boolean',
    :'recording_detail_allowed' => :'Boolean',
    :'artist_detail_allowed' => :'Boolean',
    :'playlist_prediction_allowed' => :'Boolean',
    :'widgets_allowed' => :'Boolean',
    :'signup_allowed' => :'Boolean',
    :'upload_allowed' => :'Boolean',
    :'fingerprint_allowed' => :'Boolean',
    :'audiotagging_allowed' => :'Boolean',
    :'b2b_allowed' => :'Boolean',
    :'editor_allowed' => :'Boolean',
    :'reduced_musical_features' => :'Boolean',
    :'confirmed' => :'Boolean',
    :'language' => :'String',
    :'admin' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 323

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      username == o.username &&
      email_address == o.email_address &&
      company_name == o.company_name &&
      is_admin == o.is_admin &&
      full_search_allowed == o.full_search_allowed &&
      voice_search_allowed == o.voice_search_allowed &&
      recording_detail_allowed == o.recording_detail_allowed &&
      artist_detail_allowed == o.artist_detail_allowed &&
      playlist_prediction_allowed == o.playlist_prediction_allowed &&
      widgets_allowed == o.widgets_allowed &&
       == o. &&
      upload_allowed == o.upload_allowed &&
      fingerprint_allowed == o.fingerprint_allowed &&
      audiotagging_allowed == o.audiotagging_allowed &&
      b2b_allowed == o.b2b_allowed &&
      editor_allowed == o.editor_allowed &&
      reduced_musical_features == o.reduced_musical_features &&
      confirmed == o.confirmed &&
      language == o.language &&
      admin == o.admin
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 394

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = MusicubeApiClientRuby.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 465

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 370

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


350
351
352
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 350

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



356
357
358
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 356

def hash
  [username, email_address, company_name, is_admin, full_search_allowed, voice_search_allowed, recording_detail_allowed, artist_detail_allowed, playlist_prediction_allowed, widgets_allowed, , upload_allowed, fingerprint_allowed, audiotagging_allowed, b2b_allowed, editor_allowed, reduced_musical_features, confirmed, language, admin].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 220

def list_invalid_properties
  invalid_properties = Array.new
  if @username.nil?
    invalid_properties.push('invalid value for "username", username cannot be nil.')
  end

  if @email_address.nil?
    invalid_properties.push('invalid value for "email_address", email_address cannot be nil.')
  end

  if @is_admin.nil?
    invalid_properties.push('invalid value for "is_admin", is_admin cannot be nil.')
  end

  if @full_search_allowed.nil?
    invalid_properties.push('invalid value for "full_search_allowed", full_search_allowed cannot be nil.')
  end

  if @voice_search_allowed.nil?
    invalid_properties.push('invalid value for "voice_search_allowed", voice_search_allowed cannot be nil.')
  end

  if @recording_detail_allowed.nil?
    invalid_properties.push('invalid value for "recording_detail_allowed", recording_detail_allowed cannot be nil.')
  end

  if @artist_detail_allowed.nil?
    invalid_properties.push('invalid value for "artist_detail_allowed", artist_detail_allowed cannot be nil.')
  end

  if @playlist_prediction_allowed.nil?
    invalid_properties.push('invalid value for "playlist_prediction_allowed", playlist_prediction_allowed cannot be nil.')
  end

  if @widgets_allowed.nil?
    invalid_properties.push('invalid value for "widgets_allowed", widgets_allowed cannot be nil.')
  end

  if @signup_allowed.nil?
    invalid_properties.push('invalid value for "signup_allowed", signup_allowed cannot be nil.')
  end

  if @upload_allowed.nil?
    invalid_properties.push('invalid value for "upload_allowed", upload_allowed cannot be nil.')
  end

  if @fingerprint_allowed.nil?
    invalid_properties.push('invalid value for "fingerprint_allowed", fingerprint_allowed cannot be nil.')
  end

  if @audiotagging_allowed.nil?
    invalid_properties.push('invalid value for "audiotagging_allowed", audiotagging_allowed cannot be nil.')
  end

  if @b2b_allowed.nil?
    invalid_properties.push('invalid value for "b2b_allowed", b2b_allowed cannot be nil.')
  end

  if @editor_allowed.nil?
    invalid_properties.push('invalid value for "editor_allowed", editor_allowed cannot be nil.')
  end

  if @reduced_musical_features.nil?
    invalid_properties.push('invalid value for "reduced_musical_features", reduced_musical_features cannot be nil.')
  end

  if @confirmed.nil?
    invalid_properties.push('invalid value for "confirmed", confirmed cannot be nil.')
  end

  if @language.nil?
    invalid_properties.push('invalid value for "language", language cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



441
442
443
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 441

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



447
448
449
450
451
452
453
454
455
456
457
458
459
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 447

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



435
436
437
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 435

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/musicube_api_client_ruby/models/user_dto.rb', line 299

def valid?
  return false if @username.nil?
  return false if @email_address.nil?
  return false if @is_admin.nil?
  return false if @full_search_allowed.nil?
  return false if @voice_search_allowed.nil?
  return false if @recording_detail_allowed.nil?
  return false if @artist_detail_allowed.nil?
  return false if @playlist_prediction_allowed.nil?
  return false if @widgets_allowed.nil?
  return false if @signup_allowed.nil?
  return false if @upload_allowed.nil?
  return false if @fingerprint_allowed.nil?
  return false if @audiotagging_allowed.nil?
  return false if @b2b_allowed.nil?
  return false if @editor_allowed.nil?
  return false if @reduced_musical_features.nil?
  return false if @confirmed.nil?
  return false if @language.nil?
  true
end